# Changelog

## 0.0.7 - 2022-04-05
Fix dateutil import issue

## 0.0.6 - 2022-04-05

First version of Castor Extractor, including:

- Warehouse assets extraction
  - BigQuery
  - Postgres
  - Redshift
  - Snowflake

- Visualization assets extraction
  - Looker
  - Metabase
  - Mode Analytics
  - Tableau

- Utilities
  - Uploader to cloud-storage
  - File Checker (for generic metadata)
